﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace AirFighter
{
    internal class DrawingModernAirFighter : DrawingAirFighter
    {
        public DrawingModernAirFighter(int speed, float weight, Color bodyColor, Color dopColor, bool dopWings, bool rockets) :
            base(speed, weight, bodyColor, 195, 166)
        {
           AirFighter = new EntityModernAirFighter(speed, weight, bodyColor, dopColor, dopWings, rockets);
        }
        public DrawingModernAirFighter Update(int? speed = null, float? weight = null, Color? bodyColor = null,
            Color? dopColor = null, bool? dopWings = null, bool? rockets = null)
        {
            EntityModernAirFighter entity = (EntityModernAirFighter)AirFighter;
            return new DrawingModernAirFighter(speed ?? entity.Speed, weight ?? entity.Weight, bodyColor ?? entity.BodyColor,
                                               dopColor ?? entity.DopColor, dopWings ?? entity.DopWings, rockets ?? entity.Rockets);
        }

        public override void DrawTransport(Graphics g)
        {
            if (AirFighter is not EntityModernAirFighter modernAirFighter)
            {
                return;
            }

            Pen pen = new(modernAirFighter.DopColor);
            Brush dopBrush = new SolidBrush(modernAirFighter.DopColor);

            if (modernAirFighter.DopWings)
            {
               

                PointF[] topDopWing =
                {
                    new(_startPosX + 78, _startPosY + 56),
                    new(_startPosX + 75, _startPosY + 70),
                    new(_startPosX + 55, _startPosY + 50),
                    new(_startPosX + 60, _startPosY + 45),
                };

                PointF[] bottomDopWing =
                {
                    new(_startPosX + 78, _startPosY + 110),
                    new(_startPosX + 75, _startPosY + 96),
                    new(_startPosX + 55, _startPosY + 116),
                    new(_startPosX + 60, _startPosY + 121),
                };

                g.FillPolygon(dopBrush, topDopWing);
                g.FillPolygon(dopBrush, bottomDopWing);
            }

            if (modernAirFighter.Rockets)
            {
                PointF[] topRocket1 =
                {
                    new(_startPosX + 100, _startPosY + 20),
                    new(_startPosX + 100, _startPosY + 30),
                    new(_startPosX + 112, _startPosY + 30),
                    new(_startPosX + 120, _startPosY + 25),
                    new(_startPosX + 112, _startPosY + 20)
                };

                PointF[] topRocket2 =
                {
                    new(_startPosX + 100, _startPosY + 35),
                    new(_startPosX + 100, _startPosY + 45),
                    new(_startPosX + 112, _startPosY + 45),
                    new(_startPosX + 120, _startPosY + 40),
                    new(_startPosX + 112, _startPosY + 35)
                };

                PointF[] bottomRocket1 =
                {
                    new(_startPosX + 100, _startPosY + 146),
                    new(_startPosX + 100, _startPosY + 136),
                    new(_startPosX + 112, _startPosY + 136),
                    new(_startPosX + 120, _startPosY + 141),
                    new(_startPosX + 112, _startPosY + 146)
                };

                PointF[] bottomRocket2 =
                {
                    new(_startPosX + 100, _startPosY + 131),
                    new(_startPosX + 100, _startPosY + 121),
                    new(_startPosX + 112, _startPosY + 121),
                    new(_startPosX + 120, _startPosY + 126),
                    new(_startPosX + 112, _startPosY + 131)
                };

                g.FillPolygon(dopBrush, topRocket1);
                g.FillPolygon(dopBrush, topRocket2);
                g.FillPolygon(dopBrush, bottomRocket1);
                g.FillPolygon(dopBrush, bottomRocket2);
            }


            base.DrawTransport(g);

        }
    }
}
